@@ -15,7 +15,6 @@
 #include "pmt/pmt_serial_tags.h"
 #include "pmt_int.h"
 #include <pmt/pmt.h>
-#include <boost/endian/conversion.hpp>
 #include <limits>
 #include <vector>
 
@@ -27,23 +26,51 @@ static pmt_t parse_pair(std::streambuf& sb, uint8_t type);
 // output primitives
 // ----------------------------------------------------------------
 
+static inline void native_to_big_u16(uint16_t i, uint8_t* buf)
+{
+    buf[0] = i >> 8;
+    buf[1] = i & 0xff;
+}
+
+static inline void native_to_big_u32(uint32_t i, uint8_t* buf)
+{
+    buf[0] = i >> 24;
+    buf[1] = (i >> 16) & 0xff;
+    buf[2] = (i >> 8) & 0xff;
+    buf[3] = i & 0xff;
+}
+
+static inline void native_to_big_u64(uint64_t i, uint8_t* buf)
+{
+    buf[0] = i >> 56;
+    buf[1] = (i >> 48) & 0xff;
+    buf[2] = (i >> 40) & 0xff;
+    buf[3] = (i >> 32) & 0xff;
+    buf[4] = (i >> 24) & 0xff;
+    buf[5] = (i >> 16) & 0xff;
+    buf[6] = (i >> 8) & 0xff;
+    buf[7] = i & 0xff;
+}
+
 static bool serialize_untagged_u8(uint8_t i, std::streambuf& sb)
 {
-    return sb.sputc((i >> 0) & 0xff) != std::streambuf::traits_type::eof();
+    return sb.sputc(i) != std::streambuf::traits_type::eof();
 }
 
 // always writes big-endian
 static bool serialize_untagged_u16(uint16_t i, std::streambuf& sb)
 {
-    boost::endian::native_to_big_inplace(i);
-    return sb.sputn((char*)&i, sizeof(i)) != std::streambuf::traits_type::eof();
+    uint8_t buf[sizeof(uint16_t)];
+    native_to_big_u16(i, buf);
+    return sb.sputn((char*)buf, sizeof(buf)) != std::streambuf::traits_type::eof();
 }
 
 // always writes big-endian
 static bool serialize_untagged_u32(uint32_t i, std::streambuf& sb)
 {
-    boost::endian::native_to_big_inplace(i);
-    return sb.sputn((char*)&i, sizeof(i)) != std::streambuf::traits_type::eof();
+    uint8_t buf[sizeof(uint32_t)];
+    native_to_big_u32(i, buf);
+    return sb.sputn((char*)buf, sizeof(buf)) != std::streambuf::traits_type::eof();
 }
 
 static bool serialize_untagged_f64(double i, std::streambuf& sb)
@@ -54,15 +81,17 @@ static bool serialize_untagged_f64(double i, std::streambuf& sb)
     } iu_t;
     iu_t iu;
     iu.id = i;
-    boost::endian::native_to_big_inplace(iu.ii);
-    return sb.sputn((char*)&iu.ii, sizeof(iu.ii)) != std::streambuf::traits_type::eof();
+    uint8_t buf[sizeof(uint64_t)];
+    native_to_big_u64(iu.ii, buf);
+    return sb.sputn((char*)buf, sizeof(buf)) != std::streambuf::traits_type::eof();
 }
 
 // always writes big-endian
 static bool serialize_untagged_u64(uint64_t i, std::streambuf& sb)
 {
-    boost::endian::native_to_big_inplace(i);
-    return sb.sputn((char*)&i, sizeof(i)) != std::streambuf::traits_type::eof();
+    uint8_t buf[sizeof(uint64_t)];
+    native_to_big_u64(i, buf);
+    return sb.sputn((char*)buf, sizeof(buf)) != std::streambuf::traits_type::eof();
 }
 
 // always writes big-endian
@@ -75,9 +104,9 @@ serialize_untagged_u8_array(const uint8_t* data, size_t length, std::streambuf&
 static bool
 serialize_untagged_u16_array(const uint16_t* data, size_t length, std::streambuf& sb)
 {
-    std::vector<uint16_t> bedata(length);
+    std::vector<uint8_t> bedata(length * sizeof(uint16_t));
     for (size_t i = 0; i < length; i++) {
-        bedata[i] = boost::endian::native_to_big(data[i]);
+        native_to_big_u16(data[i], &bedata[sizeof(uint16_t) * i]);
     }
     return sb.sputn((char*)&bedata[0], length * sizeof(uint16_t)) !=
            std::streambuf::traits_type::eof();
@@ -86,9 +115,9 @@ serialize_untagged_u16_array(const uint16_t* data, size_t length, std::streambuf
 static bool
 serialize_untagged_u32_array(const uint32_t* data, size_t length, std::streambuf& sb)
 {
-    std::vector<uint32_t> bedata(length);
+    std::vector<uint8_t> bedata(length * sizeof(uint32_t));
     for (size_t i = 0; i < length; i++) {
-        bedata[i] = boost::endian::native_to_big(data[i]);
+        native_to_big_u32(data[i], &bedata[sizeof(uint32_t) * i]);
     }
     return sb.sputn((char*)&bedata[0], length * sizeof(uint32_t)) !=
            std::streambuf::traits_type::eof();
@@ -97,9 +126,9 @@ serialize_untagged_u32_array(const uint32_t* data, size_t length, std::streambuf
 static bool
 serialize_untagged_u64_array(const uint64_t* data, size_t length, std::streambuf& sb)
 {
-    std::vector<uint64_t> bedata(length);
+    std::vector<uint8_t> bedata(length * sizeof(uint64_t));
     for (size_t i = 0; i < length; i++) {
-        bedata[i] = boost::endian::native_to_big(data[i]);
+        native_to_big_u64(data[i], &bedata[sizeof(uint64_t) * i]);
     }
     return sb.sputn((char*)&bedata[0], length * sizeof(uint64_t)) !=
            std::streambuf::traits_type::eof();
@@ -109,6 +138,21 @@ serialize_untagged_u64_array(const uint64_t* data, size_t length, std::streambuf
 // input primitives
 // ----------------------------------------------------------------
 
+static inline uint32_t big_to_native_u16(uint8_t* buf) { return (buf[0] << 8) | buf[1]; }
+
+static inline uint32_t big_to_native_u32(uint8_t* buf)
+{
+    return (buf[0] << 24) | (buf[1] << 16) | (buf[2] << 8) | buf[3];
+}
+
+static inline uint64_t big_to_native_u64(uint8_t* buf)
+{
+    return ((uint64_t)buf[0] << 56) | ((uint64_t)buf[1] << 48) |
+           ((uint64_t)buf[2] << 40) | ((uint64_t)buf[3] << 32) |
+           ((uint64_t)buf[4] << 24) | ((uint64_t)buf[5] << 16) | ((uint64_t)buf[6] << 8) |
+           (uint64_t)buf[7];
+}
+
 // always reads big-endian
 static bool deserialize_untagged_u8(uint8_t* ip, std::streambuf& sb)
 {
@@ -125,10 +169,11 @@ static bool deserialize_untagged_u8(uint8_t* ip, std::streambuf& sb)
 // always reads big-endian
 static bool deserialize_untagged_u16(uint16_t* ip, std::streambuf& sb)
 {
+    uint8_t buf[sizeof(uint16_t)];
     std::streambuf::traits_type::int_type t;
-    t = sb.sgetn((char*)ip, sizeof(uint16_t));
+    t = sb.sgetn((char*)buf, sizeof(buf));
     sb.pubseekoff(sizeof(uint16_t), std::ios_base::cur);
-    boost::endian::big_to_native_inplace(*ip);
+    *ip = big_to_native_u16(buf);
 
     return t != std::streambuf::traits_type::eof();
 }
@@ -136,10 +181,11 @@ static bool deserialize_untagged_u16(uint16_t* ip, std::streambuf& sb)
 // always reads big-endian
 static bool deserialize_untagged_u32(uint32_t* ip, std::streambuf& sb)
 {
+    uint8_t buf[sizeof(uint32_t)];
     std::streambuf::traits_type::int_type t;
-    t = sb.sgetn((char*)ip, sizeof(uint32_t));
+    t = sb.sgetn((char*)buf, sizeof(buf));
     sb.pubseekoff(sizeof(uint32_t), std::ios_base::cur);
-    boost::endian::big_to_native_inplace(*ip);
+    *ip = big_to_native_u32(buf);
 
     return t != std::streambuf::traits_type::eof();
 }
@@ -147,16 +193,18 @@ static bool deserialize_untagged_u32(uint32_t* ip, std::streambuf& sb)
 // always reads big-endian
 static bool deserialize_untagged_u64(uint64_t* ip, std::streambuf& sb)
 {
+    uint8_t buf[sizeof(uint64_t)];
     std::streambuf::traits_type::int_type t;
-    t = sb.sgetn((char*)ip, sizeof(uint64_t));
+    t = sb.sgetn((char*)buf, sizeof(buf));
     sb.pubseekoff(sizeof(uint64_t), std::ios_base::cur);
-    boost::endian::big_to_native_inplace(*ip);
+    *ip = big_to_native_u64(buf);
 
     return t != std::streambuf::traits_type::eof();
 }
 
 static bool deserialize_untagged_f64(double* ip, std::streambuf& sb)
 {
+    uint8_t buf[sizeof(uint64_t)];
     std::streambuf::traits_type::int_type t;
 
     typedef union {
@@ -165,9 +213,9 @@ static bool deserialize_untagged_f64(double* ip, std::streambuf& sb)
     } iu_t;
 
     iu_t iu;
-    t = sb.sgetn((char*)&iu, sizeof(uint64_t));
+    t = sb.sgetn((char*)buf, sizeof(buf));
     sb.pubseekoff(sizeof(uint64_t), std::ios_base::cur);
-    boost::endian::big_to_native_inplace(iu.ii);
+    iu.ii = big_to_native_u64(buf);
     *ip = iu.id;
 
     return t != std::streambuf::traits_type::eof();
@@ -209,10 +257,11 @@ static bool deserialize_untagged_u16_vector(std::vector<uint16_t>& data,
 {
     std::streambuf::traits_type::int_type t;
     data.resize(nitems);
-    t = sb.sgetn((char*)&data[0], nitems * sizeof(uint16_t));
+    std::vector<uint8_t> buf(nitems * sizeof(uint16_t));
+    t = sb.sgetn((char*)&buf[0], nitems * sizeof(uint16_t));
     sb.pubseekoff(sizeof(uint16_t) * nitems, std::ios_base::cur);
     for (size_t i = 0; i < nitems; i++) {
-        boost::endian::big_to_native_inplace(data[i]);
+        data[i] = big_to_native_u16(&buf[sizeof(uint16_t) * i]);
     }
 
     return t != std::streambuf::traits_type::eof();
@@ -224,10 +273,11 @@ static bool deserialize_untagged_u32_vector(std::vector<uint32_t>& data,
 {
     std::streambuf::traits_type::int_type t;
     data.resize(nitems);
-    t = sb.sgetn((char*)&data[0], nitems * sizeof(uint32_t));
+    std::vector<uint8_t> buf(nitems * sizeof(uint32_t));
+    t = sb.sgetn((char*)&buf[0], nitems * sizeof(uint32_t));
     sb.pubseekoff(sizeof(uint32_t) * nitems, std::ios_base::cur);
     for (size_t i = 0; i < nitems; i++) {
-        boost::endian::big_to_native_inplace(data[i]);
+        data[i] = big_to_native_u32(&buf[sizeof(uint32_t) * i]);
     }
 
     return t != std::streambuf::traits_type::eof();
@@ -239,10 +289,11 @@ static bool deserialize_untagged_u64_vector(std::vector<uint64_t>& data,
 {
     std::streambuf::traits_type::int_type t;
     data.resize(nitems);
-    t = sb.sgetn((char*)&data[0], nitems * sizeof(uint64_t));
+    std::vector<uint8_t> buf(nitems * sizeof(uint64_t));
+    t = sb.sgetn((char*)&buf[0], nitems * sizeof(uint64_t));
     sb.pubseekoff(sizeof(uint64_t) * nitems, std::ios_base::cur);
     for (size_t i = 0; i < nitems; i++) {
-        boost::endian::big_to_native_inplace(data[i]);
+        data[i] = big_to_native_u64(&buf[sizeof(uint64_t) * i]);
     }
 
     return t != std::streambuf::traits_type::eof();
