@@ -18,8 +18,8 @@
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <boost/format.hpp>
 #include <cstdio>
+#include <sstream>
 #include <stdexcept>
 
 #ifdef _MSC_VER
@@ -99,18 +99,18 @@ bool file_source_impl::seek(int64_t seek_point, int whence)
             seek_point = d_length_items - seek_point;
             break;
         default:
-            GR_LOG_WARN(d_logger, "bad seek mode");
+            d_logger->warn("bad seek mode {:d}", whence);
             return 0;
         }
 
         if ((seek_point < (int64_t)d_start_offset_items) ||
             (seek_point > (int64_t)(d_start_offset_items + d_length_items - 1))) {
-            GR_LOG_WARN(d_logger, "bad seek point");
+            d_logger->warn("bad seek point {:d}", seek_point);
             return 0;
         }
         return GR_FSEEK((FILE*)d_fp, seek_point * d_itemsize, SEEK_SET) == 0;
     } else {
-        GR_LOG_WARN(d_logger, "file not seekable");
+        d_logger->warn("file not seekable");
         return 0;
     }
 }
@@ -130,14 +130,14 @@ void file_source_impl::open(const char* filename,
     }
 
     if ((d_new_fp = fopen(filename, "rb")) == NULL) {
-        GR_LOG_ERROR(d_logger, boost::format("%s: %s") % filename % strerror(errno));
+        d_logger->error("[fopen] {:s}: {:s}", filename, strerror(errno));
         throw std::runtime_error("can't open file");
     }
 
     struct GR_STAT st;
 
     if (GR_FSTAT(GR_FILENO(d_new_fp), &st)) {
-        GR_LOG_ERROR(d_logger, boost::format("%s: %s") % filename % strerror(errno));
+        d_logger->error("[fstat] {:s}: {:s}", filename, strerror(errno));
         throw std::runtime_error("can't fstat file");
     }
     if (S_ISREG(st.st_mode)) {
@@ -158,9 +158,11 @@ void file_source_impl::open(const char* filename,
         // Make sure there will be at least one item available
         if ((file_size / d_itemsize) < (start_offset_items + 1)) {
             if (start_offset_items) {
-                GR_LOG_WARN(d_logger, "file is too small for start offset");
+                d_logger->warn("file is too small for start offset: {:d} < {:d}",
+                               file_size - 1,
+                               start_offset_items * d_itemsize);
             } else {
-                GR_LOG_WARN(d_logger, "file is too small");
+                d_logger->warn("file is too small ({:d})", file_size);
             }
             fclose(d_new_fp);
             throw std::runtime_error("file is too small");
@@ -174,16 +176,21 @@ void file_source_impl::open(const char* filename,
     // If length is not specified, use the remainder of the file. Check alignment at end.
     if (length_items == 0) {
         length_items = items_available;
-        if (file_size % d_itemsize) {
-            GR_LOG_WARN(d_logger, "file size is not a multiple of item size");
+        if (d_seekable && (file_size % d_itemsize)) {
+            d_logger->warn("file size is not a multiple of item size ({:d} ≠ N·{:d})",
+                           file_size,
+                           d_itemsize);
         }
     }
 
     // Check specified length. Warn and use available items instead of throwing an
     // exception.
     if (length_items > items_available) {
+        d_logger->warn(
+            "file too short, will read fewer than requested items: {:d} > {:d}",
+            length_items,
+            items_available);
         length_items = items_available;
-        GR_LOG_WARN(d_logger, "file too short, will read fewer than requested items");
     }
 
     // Rewind to start offset
@@ -202,15 +209,13 @@ void file_source_impl::open(const char* filename,
         if (file_size && file_size != INT64_MAX) {
             if (auto ret = posix_fadvise(
                     fd, start_offset, file_size - start_offset, POSIX_FADV_SEQUENTIAL)) {
-                GR_LOG_WARN(d_logger,
-                            "failed to advise to read sequentially, " +
-                                fadv_errstrings.at(ret));
+                d_logger->warn("failed to advise to read sequentially, {:s}",
+                               fadv_errstrings.at(ret));
             }
             if (auto ret = posix_fadvise(
                     fd, start_offset, file_size - start_offset, POSIX_FADV_WILLNEED)) {
-                GR_LOG_WARN(d_logger,
-                            "failed to advise we'll need file contents soon, " +
-                                fadv_errstrings.at(ret));
+                d_logger->warn("failed to advise we'll need file contents soon, {:s}",
+                               fadv_errstrings.at(ret));
             }
         }
 #endif
