@@ -13,8 +13,6 @@
 #include "dvbt_bit_inner_deinterleaver_impl.h"
 #include <gnuradio/io_signature.h>
 
-#include <boost/format.hpp>
-
 #define MAX_MODULATION_ORDER 6
 #define INTERLEAVER_BLOCK_SIZE 126
 
@@ -65,11 +63,10 @@ dvbt_bit_inner_deinterleaver_impl::dvbt_bit_inner_deinterleaver_impl(
     }
 
     if (d_nsize % d_bsize) {
-        GR_LOG_ERROR(
-            d_logger,
-            boost::format(
-                "Input size must be multiple of block size: nsize: %1% bsize: %2%") %
-                d_nsize % d_bsize);
+        this->d_logger->error(
+            "Input size must be multiple of block size: nsize: {:d} bsize: {:d}",
+            d_nsize,
+            d_bsize);
     }
 }
 
