@@ -1,8 +1,6 @@
 import warnings
 import argparse
-import os
 from gnuradio.bindtool import BindingGenerator
-import pathlib
 import sys
 import tempfile
 
@@ -13,8 +11,6 @@ parser.add_argument('--module', type=str,
 parser.add_argument('--output_dir', default=tempfile.gettempdir(),
                     help='Output directory of generated bindings')
 parser.add_argument('--prefix', help='Prefix of Installed GNU Radio')
-parser.add_argument('--src', help='Directory of gnuradio source tree',
-                    default=os.path.dirname(os.path.abspath(__file__)) + '/../../..')
 
 parser.add_argument(
     '--filename', help="File to be parsed")
