@@ -15,7 +15,6 @@
 #include "req_msg_source_impl.h"
 #include "tag_headers.h"
 #include <gnuradio/io_signature.h>
-#include <boost/thread/thread.hpp>
 #include <chrono>
 #include <memory>
 #include <thread>
@@ -61,7 +60,7 @@ req_msg_source_impl::~req_msg_source_impl() {}
 bool req_msg_source_impl::start()
 {
     d_finished = false;
-    d_thread = std::make_unique<boost::thread>([this] { readloop(); });
+    d_thread = std::make_unique<std::thread>([this] { readloop(); });
     return true;
 }
 
@@ -110,7 +109,7 @@ void req_msg_source_impl::readloop()
 #endif
             if (!ok) {
                 // Should not happen, we've checked POLLIN.
-                GR_LOG_ERROR(d_logger, "Failed to receive message.");
+                d_logger->error("Failed to receive message.");
                 std::this_thread::sleep_for(100us);
                 continue;
             }
@@ -121,7 +120,7 @@ void req_msg_source_impl::readloop()
                 pmt::pmt_t m = pmt::deserialize(sb);
                 message_port_pub(d_port, m);
             } catch (pmt::exception& e) {
-                GR_LOG_ERROR(d_logger, std::string("Invalid PMT message: ") + e.what());
+                d_logger->error("Invalid PMT message: {:s}", e.what());
             }
 
         } else {
